Crate compio_driver

Crate compio_driver 

Platform-specific drivers.

Some types differ by compilation target.

Modules

op
The async operations.

Structs

AsyncifyPool
A thread pool to perform blocking operations in other threads.
BorrowedFd
A borrowed file descriptor.
BoxAllocator
Default implementation of BufferAllocator.
BufferPool
A buffer pool.
BufferRef
A unique reference to a buffer within the buffer pool.
Cancel
A type-erased cancel token.
DispatchError
An error that may be emitted when all worker threads are busy.
Extra
Platform-specific extra data associated with a driver instance.
Key
A typed wrapper for key of Ops submitted into driver.
OwnedFd
An owned file descriptor.
Proactor
Low-level actions of completion-based IO. It owns the operations to keep the driver safe.
ProactorBuilder
Builder for Proactor.
SharedFd
A shared fd. It is passed to the operations to make sure the fd won’t be closed before the operations complete.
WaitArg
Meta of polling operations.

Enums

Decision
Result of OpCode::pre_submit.
DriverType
Representing underlying driver type the fusion driver is using
OpEntry
The created entry of OpCode.
OpType
Represents the filter type of kqueue. polling crate doesn’t expose such API, and we need to know about it when cancel is called.
PushEntry
The return type of Proactor::push.

Traits

AsFd
A trait to borrow the file descriptor from an underlying object.
AsRawFd
A trait to extract the raw file descriptor from an underlying object.
BufferAllocator
Trait used to allocate buffers for compio-driver’s buffer pool.
Dispatchable
A trait for dispatching a closure.
ErrorExt
Extension trait for io::Error and results with it.
FromRawFd
A trait to express the ability to construct an object from a raw file descriptor.
IntoRawFd
A trait to express the ability to consume an object and acquire ownership of its raw file descriptor.
IourOpCode
Abstraction of io-uring operations.
OpCode
Fused OpCode
PollOpCode
Abstraction of operations.
ResultTakeBuffer
Helper trait for taking buffer from a BufResult.
TakeBuffer
Take buffer out of an operation.
ToSharedFd
Get a clone of SharedFd.

Type Aliases

RawFdNon-Hermit and non-Motor OS
Raw file descriptors.