OpCodeFlag

Struct OpCodeFlag 

pub struct OpCodeFlag(/* private fields */);
Flags for operations.

Implementations

Source

impl OpCodeFlag

pub const Read: Self

Detect Read OpCode

pub const Readv: Self

Detect Readv OpCode

pub const Write: Self

Detect Write OpCode

pub const Writev: Self

Detect Writev OpCode

pub const Fsync: Self

Detect Fsync OpCode

pub const Accept: Self

Detect Accept OpCode

pub const Connect: Self

Detect Connect OpCode

pub const Recv: Self

Detect Recv OpCode

pub const Send: Self

Detect Send OpCode

pub const RecvMsg: Self

Detect RecvMsg OpCode

pub const SendMsg: Self

Detect SendMsg OpCode

pub const AsyncCancel: Self

Detect AsyncCancel OpCode

pub const OpenAt: Self

Detect OpenAt OpCode

pub const Close: Self

Detect Close OpCode

pub const Splice: Self

Detect Splice OpCode

pub const Shutdown: Self

Detect Shutdown OpCode

pub const PollAdd: Self

Detect PollAdd OpCode

Source

impl OpCodeFlag

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in self are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in other are also set in self.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in other are also set in self.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in self and other.

pub fn remove(&mut self, other: Self)

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in self and other.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in self and other.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in self and other.

pub const fn difference(self, other: Self) -> Self

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in self and other.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in self, truncating the result.

Source

impl OpCodeFlag

pub const fn iter(&self) -> Iter<OpCodeFlag>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<OpCodeFlag>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl OpCodeFlag

pub fn basic() -> Self

Get the OpCodeFlag corresponds to basic OpCodes that are commonly used.