pub struct ReturnFlags(/* private fields */);Implementations
Sourceimpl ReturnFlags
impl ReturnFlags
Sourcepub const OOB: ReturnFlags
pub const OOB: ReturnFlags
MSG_OOB
Sourcepub const EOR: ReturnFlags
pub const EOR: ReturnFlags
MSG_EOR
Sourcepub const TRUNC: ReturnFlags
pub const TRUNC: ReturnFlags
MSG_TRUNC
Sourcepub const CTRUNC: ReturnFlags
pub const CTRUNC: ReturnFlags
MSG_CTRUNC
Sourcepub const ERRQUEUE: ReturnFlags
pub const ERRQUEUE: ReturnFlags
MSG_ERRQUEUE
Sourcepub const CMSG_CLOEXEC: ReturnFlags
pub const CMSG_CLOEXEC: ReturnFlags
MSG_CMSG_CLOEXEC
Sourceimpl ReturnFlags
impl ReturnFlags
Sourcepub const fn empty() -> ReturnFlags
pub const fn empty() -> ReturnFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> ReturnFlags
pub const fn all() -> ReturnFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<ReturnFlags>
pub const fn from_bits(bits: u32) -> Option<ReturnFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> ReturnFlags
pub const fn from_bits_truncate(bits: u32) -> ReturnFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> ReturnFlags
pub const fn from_bits_retain(bits: u32) -> ReturnFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<ReturnFlags>
pub fn from_name(name: &str) -> Option<ReturnFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: ReturnFlags) -> bool
pub const fn intersects(&self, other: ReturnFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: ReturnFlags) -> bool
pub const fn contains(&self, other: ReturnFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: ReturnFlags)
pub fn insert(&mut self, other: ReturnFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: ReturnFlags)
pub fn remove(&mut self, other: ReturnFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: ReturnFlags)
pub fn toggle(&mut self, other: ReturnFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: ReturnFlags, value: bool)
pub fn set(&mut self, other: ReturnFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: ReturnFlags) -> ReturnFlags
pub const fn intersection(self, other: ReturnFlags) -> ReturnFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: ReturnFlags) -> ReturnFlags
pub const fn union(self, other: ReturnFlags) -> ReturnFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: ReturnFlags) -> ReturnFlags
pub const fn difference(self, other: ReturnFlags) -> ReturnFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: ReturnFlags) -> ReturnFlags
pub const fn symmetric_difference(self, other: ReturnFlags) -> ReturnFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> ReturnFlags
pub const fn complement(self) -> ReturnFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl ReturnFlags
impl ReturnFlags
Sourcepub const fn iter(&self) -> Iter<ReturnFlags> ⓘ
pub const fn iter(&self) -> Iter<ReturnFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ReturnFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<ReturnFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.