pub struct SpliceFlags(/* private fields */);Implementations
Sourceimpl SpliceFlags
impl SpliceFlags
Sourcepub const MOVE: SpliceFlags
pub const MOVE: SpliceFlags
SPLICE_F_MOVE
Sourcepub const NONBLOCK: SpliceFlags
pub const NONBLOCK: SpliceFlags
SPLICE_F_NONBLOCK
Sourcepub const MORE: SpliceFlags
pub const MORE: SpliceFlags
SPLICE_F_MORE
Sourcepub const GIFT: SpliceFlags
pub const GIFT: SpliceFlags
SPLICE_F_GIFT
Sourceimpl SpliceFlags
impl SpliceFlags
Sourcepub const fn empty() -> SpliceFlags
pub const fn empty() -> SpliceFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> SpliceFlags
pub const fn all() -> SpliceFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<SpliceFlags>
pub const fn from_bits(bits: u32) -> Option<SpliceFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> SpliceFlags
pub const fn from_bits_truncate(bits: u32) -> SpliceFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> SpliceFlags
pub const fn from_bits_retain(bits: u32) -> SpliceFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<SpliceFlags>
pub fn from_name(name: &str) -> Option<SpliceFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: SpliceFlags) -> bool
pub const fn intersects(&self, other: SpliceFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: SpliceFlags) -> bool
pub const fn contains(&self, other: SpliceFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: SpliceFlags)
pub fn insert(&mut self, other: SpliceFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: SpliceFlags)
pub fn remove(&mut self, other: SpliceFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: SpliceFlags)
pub fn toggle(&mut self, other: SpliceFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: SpliceFlags, value: bool)
pub fn set(&mut self, other: SpliceFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: SpliceFlags) -> SpliceFlags
pub const fn intersection(self, other: SpliceFlags) -> SpliceFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: SpliceFlags) -> SpliceFlags
pub const fn union(self, other: SpliceFlags) -> SpliceFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: SpliceFlags) -> SpliceFlags
pub const fn difference(self, other: SpliceFlags) -> SpliceFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: SpliceFlags) -> SpliceFlags
pub const fn symmetric_difference(self, other: SpliceFlags) -> SpliceFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> SpliceFlags
pub const fn complement(self) -> SpliceFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl SpliceFlags
impl SpliceFlags
Sourcepub const fn iter(&self) -> Iter<SpliceFlags> ⓘ
pub const fn iter(&self) -> Iter<SpliceFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SpliceFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<SpliceFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.