BufResultExt

Trait BufResultExt 

pub trait BufResultExt {
    // Required method
    unsafe fn map_advanced(self) -> Self;
}
Trait to update the buffer length inside the BufResult.

Required Methods

unsafe fn map_advanced(self) -> Self

Call SetLen::advance_to if the result is Ok.

Safety

The result value must be a valid length to advance to.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T: SetLen + IoBuf> BufResultExt for BufResult<usize, T>

Source

unsafe fn map_advanced(self) -> Self

Source

impl<T: SetLen + IoBuf, C: SetLen + IoBuf, O1, O2> BufResultExt for BufResult<(usize, usize, O1, O2), (T, C)>

Source

unsafe fn map_advanced(self) -> Self

Source

impl<T: SetLen + IoBuf, C: SetLen + IoBuf, O> BufResultExt for BufResult<(usize, usize, O), (T, C)>

Source

unsafe fn map_advanced(self) -> Self

Source

impl<T: SetLen + IoBuf, O> BufResultExt for BufResult<(usize, O), T>

Source

unsafe fn map_advanced(self) -> Self

Implementors