pub struct BufferPool { /* private fields */ }Expand description
A buffer pool.
This type by itself does nothing, and should only be used by *Managed ops.
Implementations
Sourceimpl BufferPool
impl BufferPool
Sourcepub fn pop(&self) -> Result<BufferRef>
pub fn pop(&self) -> Result<BufferRef>
Pop an available buffer from the pool with given capacity.
This operation is not supported on io-uring driver and will always
return Unsupported.