Proactor

Struct Proactor 

pub struct Proactor { /* private fields */ }
Low-level actions of completion-based IO. It owns the operations to keep the driver safe.

Implementations

Source

impl Proactor

pub fn new() -> Result<Self>

Create Proactor with 1024 entries.

pub fn builder() -> ProactorBuilder

Create ProactorBuilder to config the proactor.

pub fn default_extra(&self) -> Extra

Get a default Extra for underlying driver.

pub fn driver_type(&self) -> DriverType

The current driver type.

pub fn attach(&mut self, fd: RawFd) -> Result<()>

Attach an fd to the driver.

Platform specific
  • IOCP: it will be attached to the completion port. An fd could only be attached to one driver, and could only be attached once, even if you try_clone it.
  • io-uring & polling: it will do nothing but return Ok(()).
pub fn cancel<T: OpCode>(&mut self, key: Key<T>) -> Option<BufResult<usize, T>>

Cancel an operation with the pushed Key.

Returns the result if the key is unique and the operation is completed.

The cancellation is not reliable. The underlying operation may continue, but just don’t return from Proactor::poll.

pub fn cancel_token(&mut self, token: Cancel) -> bool

Cancel an operation with a Cancel token.

Returns if a cancellation has been issued.

The cancellation is not reliable. The underlying operation may continue, but just don’t return from Proactor::pop. This will do nothing if the operation has already been completed or cancelled before.

pub fn register_cancel<T: OpCode>(&mut self, key: &Key<T>) -> Cancel

Create a Cancel that can be used to cancel the operation even without the key.

This acts like a weak reference to the Key, but can only be used to cancel the operation with Proactor::cancel_token. Extra copy of Key may cause Proactor::pop to panic while keys registered as Cancel will not. So this is useful in cases where you’re not sure if the operation will be cancelled.

pub fn push<T: OpCode + 'static>( &mut self, op: T, ) -> PushEntry<Key<T>, BufResult<usize, T>>

Push an operation into the driver, and return the unique key Key, associated with it.

pub fn push_with_extra<T: OpCode + 'static>( &mut self, op: T, extra: Extra, ) -> PushEntry<Key<T>, BufResult<usize, T>>

Push an operation into the driver with user-defined Extra, and return the unique key Key, associated with it.

pub fn poll(&mut self, timeout: Option<Duration>) -> Result<()>

Poll the driver and get completed entries. You need to call Proactor::pop to get the pushed operations.

pub fn pop<T: OpCode>( &mut self, key: Key<T>, ) -> PushEntry<Key<T>, BufResult<usize, T>>

Get the pushed operations from the completion entries.

Panics

This function will panic if the Key is not unique or if the operation is blocking and it panicked in the thread pool.

pub fn pop_with_extra<T: OpCode>( &mut self, key: Key<T>, ) -> PushEntry<Key<T>, (BufResult<usize, T>, Extra)>

Get the pushed operations from the completion entries along the Extra associated.

Panics

This function will panic if the Key is not unique or if the operation is blocking and it panicked in the thread pool.

pub fn pop_multishot<T: OpCode>( &mut self, key: &Key<T>, ) -> Option<BufResult<usize, Extra>>

Get one completion entry for a multishot operation. If it returns None, the user should call Proactor::pop_with_extra to get the final result of the operation.

pub fn update_waker<T>(&mut self, op: &Key<T>, waker: &Waker)

Update the waker of the specified op.

pub fn waker(&self) -> Waker

Create a waker to interrupt the inner driver.

pub fn register_files(&self, fds: &[RawFd]) -> Result<()>

Register file descriptors for fixed-file operations with io_uring.

This only works on io_uring driver. It will return an Unsupported error on other drivers.

pub fn unregister_files(&self) -> Result<()>

Unregister previously registered file descriptors.

This only works on io_uring driver. It will return an Unsupported error on other drivers.

pub fn register_personality(&self) -> Result<u16>

Register a new personality in io-uring driver.

Returns the personality id, which can be used with Extra::set_personality to set the personality for an operation.

This only works on io_uring driver. It will return an Unsupported error on other drivers. See Submitter::register_personality for more.

pub fn unregister_personality(&self, personality: u16) -> Result<()>

Unregister the given personality in io-uring driver.

This only works on io_uring driver. It will return an Unsupported error on other drivers. See Submitter::unregister_personality for more.

pub fn buffer_pool(&mut self) -> Result<BufferPool>

Get the buffer pool of the driver.

This will lazily initialize the pool at the first time it’s accessed, and future access to the pool will be cheap and infallible.