Platform-specific drivers.
Some types differ by compilation target.
Modules
- op
- The async operations.
Structs
- Asyncify
Pool - A thread pool to perform blocking operations in other threads.
- Borrowed
Fd - A borrowed file descriptor.
- BoxAllocator
- Default implementation of
BufferAllocator. - Buffer
Pool - A buffer pool.
- Buffer
Ref - A unique reference to a buffer within the buffer pool.
- Cancel
- A type-erased cancel token.
- Dispatch
Error - An error that may be emitted when all worker threads are busy.
- Extra
- Platform-specific extra data associated with a driver instance.
- Key
- A typed wrapper for key of Ops submitted into driver.
- OwnedFd
- An owned file descriptor.
- Proactor
- Low-level actions of completion-based IO. It owns the operations to keep the driver safe.
- Proactor
Builder - Builder for
Proactor. - Shared
Fd - A shared fd. It is passed to the operations to make sure the fd won’t be closed before the operations complete.
- WaitArg
- Meta of polling operations.
Enums
- Decision
- Result of
OpCode::pre_submit. - Driver
Type - Representing underlying driver type the fusion driver is using
- OpEntry
- The created entry of
OpCode. - OpType
- Represents the filter type of kqueue.
pollingcrate doesn’t expose such API, and we need to know about it whencancelis called. - Push
Entry - The return type of
Proactor::push.
Traits
- AsFd
- A trait to borrow the file descriptor from an underlying object.
- AsRawFd
- A trait to extract the raw file descriptor from an underlying object.
- Buffer
Allocator - Trait used to allocate buffers for compio-driver’s buffer pool.
- Dispatchable
- A trait for dispatching a closure.
- Error
Ext - Extension trait for
io::Errorand results with it. - From
RawFd - A trait to express the ability to construct an object from a raw file descriptor.
- Into
RawFd - A trait to express the ability to consume an object and acquire ownership of its raw file descriptor.
- Iour
OpCode - Abstraction of io-uring operations.
- OpCode
- Fused
OpCode - Poll
OpCode - Abstraction of operations.
- Result
Take Buffer - Helper trait for taking buffer from a
BufResult. - Take
Buffer - Take buffer out of an operation.
- ToShared
Fd - Get a clone of
SharedFd.
Type Aliases
- RawFd
Non-Hermit and non-Motor OS - Raw file descriptors.