pub trait BufResultExt {
// Required method
unsafe fn map_advanced(self) -> Self;
}Expand description
Trait to update the buffer length inside the BufResult.
Required Methods
Sourceunsafe fn map_advanced(self) -> Self
unsafe fn map_advanced(self) -> Self
Call SetLen::advance_to if the result is Ok.
Safety
The result value must be a valid length to advance to.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".