pub struct BufferPool { /* private fields */ }Expand description
A buffer pool.
This type by itself does nothing, and should only be used by *Managed ops.
Implementations
Sourceimpl BufferPool
impl BufferPool
Sourcepub fn pop(&self) -> Result<BufferRef>
pub fn pop(&self) -> Result<BufferRef>
Pop an available buffer from the pool with given capacity.
This operation is not supported on io-uring driver and will always
return Unsupported.
Sourcepub fn take(&self, buffer_id: u16) -> Result<Option<BufferRef>>
pub fn take(&self, buffer_id: u16) -> Result<Option<BufferRef>>
Take the indicated buffer from the pool.
Returns None if the buffer is not reset back yet or does not exist.
Sourcepub fn reset(&self, buffer_id: u16) -> Result<bool>
pub fn reset(&self, buffer_id: u16) -> Result<bool>
Reset the buffer_id so that it’s available for kernel to use, return
whether a buffer has been reset.
This is the same as take(buffer_id) and immediately drop it.
Sourcepub fn is_io_uring(&self) -> Result<bool>
Available on fusion only.
pub fn is_io_uring(&self) -> Result<bool>
fusion only.Test if the buffer pool is an io_uring one.